@@ -11,12 +11,8 @@ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
-import os
-import xlrd
 from tropofy.database import DBSession
-from pyramid import threadlocal
-from tropofy.database import read_write_xl
-from sqlalchemy.orm import _mapper_registry, mapperlib, class_mapper, ColumnProperty
+from sqlalchemy.orm import _mapper_registry, class_mapper, ColumnProperty
 
 
 class DbManager():
