@@ -39,7 +39,7 @@ class Form(Widget):
         :param disabled: (optional) If true, form element will be disabled
         :type disabled: bool
         :param options: (optional - used if input_type=='select') Valid options that this element may take.
-        :type options: list of :class:`tropofy.widgets.Form.Element.Option`
+        :type options: list of strings or list of :class:`tropofy.widgets.Form.Element.Option`
         :param compute_options_from: (optional - used if input_type=='select' and options=None). String matching the `name` of a dependent_option_list of a :class:`tropofy.Form.Element.Option` within a :class:`tropofy.Form.Element` in this widget.
         :type compute_options_from: str
         """
@@ -86,10 +86,10 @@ class Form(Widget):
             return self.input_type == 'select'
 
         def _process_options(self, options):
-            """Convert to list of :class:`tropofy.widgets.Form.Element.Option` from old option formats:
+            """Convert to list of :class:`tropofy.widgets.Form.Element.Option` from option formats:
 
-            For backward compatibility (<= 0.36.3). Enables options to be input in multiple formats.
-            strings or list of dictionaries - {value: <value>, text: <text>}, where <text> is the text displayed in the select and <value> the value submitted with the form.
+            Options allowed to be input as list of strings or list of dictionaries - {value: <value>, text: <text>},
+            where <text> is the text displayed in the select and <value> the value submitted with the form.
 
             :rtype: list of :class:`tropofy.widgets.Form.Element.Option`
             """
